@@ -1,8 +1,9 @@
+import copy
 import re
 import wrapt
 from operator import methodcaller
 
-from aws_xray_sdk.ext.dbapi2 import XRayTracedConn
+from aws_xray_sdk.ext.dbapi2 import XRayTracedConn, XRayTracedCursor
 
 
 def patch():
@@ -12,6 +13,11 @@ def patch():
         'connect',
         _xray_traced_connect
     )
+    wrapt.wrap_function_wrapper(
+        'psycopg2.extensions',
+        'register_type',
+        _xray_register_type_fix
+    )
 
 
 def _xray_traced_connect(wrapped, instance, args, kwargs):
@@ -32,3 +38,11 @@ def _xray_traced_connect(wrapped, instance, args, kwargs):
     }
 
     return XRayTracedConn(conn, meta)
+
+def _xray_register_type_fix(wrapped, instance, args, kwargs):
+    """Send the actual connection or curser to register type."""
+    our_args = list(copy.copy(args))
+    if len(our_args) == 2 and isinstance(our_args[1], (XRayTracedConn, XRayTracedCursor)):
+        our_args[1] = our_args[1].__wrapped__
+
+    return wrapped(*our_args, **kwargs)
